@@ -82,7 +82,7 @@ class Scorer:
     def preparePrediction(self, inputArray):
         # for classification task the shape can be (recordcount?, predictions, classCount)
         isOneHotEncode = inputArray.shape[-1] == self.numClasses
-        return inputArray.reshape(-1, self.numClasses) if isOneHotEncode else inputArray.reshape(-1)
+        return inputArray.reshape(-1, self.numClasses) if isOneHotEncode else inputArray.reshape(-1, 1)
 
     def prepareTruth(self, inputArray):
         """flatten and squeeze the truth array"""
